@@ -3,7 +3,7 @@ from django.conf import settings
 from django.core.urlresolvers import get_script_prefix
 from django.template.response import TemplateResponse
 
-from models import ViewPoint
+from models import ViewPoint, Subsite
 
 registered_view_points = set()
 
@@ -22,18 +22,22 @@ class DockitCMSMiddleware(object):
         
         if prefix and chomped_url.startswith(prefix):
             chomped_url = chomped_url[len(prefix)-1:]
+        
         #TODO find a more efficient way to do this
-        for view_point in ViewPoint.objects.all():
-            if view_point.url_regexp.match(chomped_url):
-                if view_point.pk not in registered_view_points:
-                    view_point.register_view_point()
-                    registered_view_points.add(view_point.pk)
-                try:
-                    response = view_point.dispatch(request)
-                except Http404:
-                    pass
-                else:
-                    if isinstance(response, TemplateResponse):
-                        response.render()
-                    return response
+        subsites = Subsite.objects.filter(sites=settings.SITE_ID)
+        for subsite in subsites:
+            view_points = ViewPoint.objects.filter(subsite=subsite)
+            for view_point in view_points:
+                if view_point.url_regexp.match(chomped_url):
+                    if view_point.pk not in registered_view_points:
+                        view_point.register_view_point()
+                        registered_view_points.add(view_point.pk)
+                    try:
+                        response = view_point.dispatch(request)
+                    except Http404:
+                        pass
+                    else:
+                        if isinstance(response, TemplateResponse):
+                            response.render()
+                        return response
         return response
